@@ -6,7 +6,7 @@
 # Imports =====================================================================
 import pytest
 
-from dhtmlparser.specialdict import SpecialDict
+from dhtmlparser.specialdict import SpecialDict, _lower_if_str
 
 
 # Variables ===================================================================
@@ -60,4 +60,19 @@ def test_get_function():
     assert sd.get("a") == 1
 
     assert not sd.get("y")
-    assert sd.get("y", "Nope") == "Nope"
\ No newline at end of file
+    assert sd.get("y", "Nope") == "Nope"
+
+
+def test_quality():
+    first = SpecialDict({1:2, 2:3, 3:4})
+    second = SpecialDict({3:4, 2:3, 1:2})
+
+    assert first == second
+
+    assert SpecialDict({"a": "b", "B": "a"}) == SpecialDict({"A": "b", "b": "a"})
+
+
+def test_lower_if_str():
+    assert _lower_if_str("ASD") == "asd"
+    assert _lower_if_str(u"ASD") == u"asd"
+    assert _lower_if_str(123) == 123
